@@ -1,18 +1,11 @@
-#!/usr/bin/env python
-# -*- coding:utf-8 -*-
+# -*- coding: UTF-8 -*-
+'''
+@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
+@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/B1V6KeXc7IOEB8DgXLWv3g
+@个人网站      ：www.python-office.com
+@代码日期    ：2023/8/22 23:28
+'''
 
-#############################################
-# File Name: 文件.py
-# Mail: 1957875073@qq.com
-# Created Time:  2022-4-25 10:17:34
-# Description: 有关 文件 的自动化操作
-#############################################
-# from office.lib.utils.except_utils import except_dec
-# from office.core.FileType import pofile
-# from office.core.SearchByContentType import MainSearchByContent
-
-# pofile = pofile()
-# mainSearchByContent = MainSearchByContent()
 import pofile
 import search4file
 
@@ -22,28 +15,48 @@ from office.lib.decorator_utils.instruction_url import instruction
 
 
 @instruction
-def replace4filename(path, del_content, replace_content=None):
-    pofile.replace4filename(path, del_content, replace_content)
+def replace4filename(path: str, del_content, replace_content='', dir_rename: bool = True,
+                     file_rename: bool = True, suffix=None):
+    """
+    批量修改文件/文件夹名称
+    :param path: 必填，需要修改文件夹/文件名称的根目录，注意：该根目录名称不会被修改
+    :param del_content: 必填，需要替换/删除的内容
+    :param replace_content: 选填，替换后的内容，不填则实现删除效果
+    :param dir_rename: 选填，是否修改文件夹名称，默认：修改
+    :param file_rename: 选填，是否修改文件名称，默认：修改
+    :param suffix: 选填，指定修改的文件类型，默认：所有
+    :return:
+    """
+    pofile.replace4filename(path, del_content, replace_content, dir_rename, file_rename, suffix)
 
 
 # todo：输入文件路径
 # @except_dec()
 @instruction
-def search_by_content(search_path, content):  # 定义 search() 函数，传入 "path" 文件路径， "target" 要查找的目标文件
+def search_by_content(search_path: str, content: str):
+    """
+    通过内容搜索文件
+    Args:
+        search_path: 需要搜索的目录
+        content: 搜索的内容
+
+    Returns:
+
+    """
     search4file.search_by_content(search_path=search_path, search_content=content)
 
 
 # author：https://github.com/CoderWanFeng/python-office/pull/72
 # @except_dec()
 @instruction
-def file_name_insert_content(file_path, insert_position: int, insert_content: str):
+def file_name_insert_content(file_path: str, insert_position: int, insert_content: str):
     pofile.file_name_insert_content(file_path, insert_position, insert_content)
 
 
 # author：https://github.com/CoderWanFeng/python-office/pull/72
 # @except_dec()
 @instruction
-def file_name_add_prefix(file_path, prefix_content):
+def file_name_add_prefix(file_path: str, prefix_content: str):
     pofile.file_name_add_prefix(file_path, prefix_content)
 
 
