@@ -1,22 +1,16 @@
-#!/usr/bin/env python
-# -*- coding:utf-8 -*-
-
-#############################################
-# File Name: 图片.py
-# Mail: 1957875073@qq.com
-# Created Time:  2022-4-25 10:17:34
-# Description: 有关 图片 的自动化操作
-#############################################
+# -*- coding: UTF-8 -*-
+'''
+@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
+@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/B1V6KeXc7IOEB8DgXLWv3g
+@个人网站      ：www.python-office.com
+@代码日期    ：2023/8/22 23:28
+'''
 import poimage
 
 # @except_dec()
 from office.lib.decorator_utils.instruction_url import instruction
 
 
-# from office.core.ImageType import MainImage
-# from office.lib.utils.except_utils import except_dec
-# mainImage = MainImage()
-
 def compress_image(input_file: str, output_file: str, quality: int):
     poimage.compress_image(input_file, output_file, quality)
 
@@ -29,8 +23,23 @@ def image2gif():
 # todo：输出文件路径
 # @except_dec()
 @instruction
-def add_watermark(file, mark, output_path=r'./mark_img', color="#8B8B1B", size=30, opacity=0.15, space=75,
+def add_watermark(file, mark, output_path='./mark_img', color="#8B8B1B", size=50, opacity=0.02, space=200,
                   angle=30):
+    """
+    给图片加水印
+    Args:
+        file: 图片位置
+        mark: 水印内容
+        output_path: 输出位置
+        color: 水印颜色
+        size: 水印大小
+        opacity: 不透明度，0.01~1
+        space: 水印间距
+        angle: 水印角度
+
+    Returns:
+
+    """
     poimage.add_watermark(file, mark, output_path, color, size, opacity, space, angle)
     # mainImage.add_watermark(file, mark, out, color, size, opacity, space, angle)
 
@@ -68,3 +77,7 @@ def decode_qrcode(qrcode_path):
     :return:
     """
     poimage.decode_qrcode(qrcode_path)
+
+@instruction
+def del_watermark(input_image, output_image=r'./del_water_mark.jpg'):
+    poimage.del_watermark(input_image, output_image)
